componenttools.get_lineage_of_component_that_start_with_component
=================================================================

.. autofunction:: abjad.tools.componenttools.get_lineage_of_component_that_start_with_component.get_lineage_of_component_that_start_with_component
   :noindex:
